@@ -41,8 +41,10 @@ from jsw_nx.packages.sleep_random import sleep_random
 from jsw_nx.packages.uniq import uniq
 
 # next classes
+from jsw_nx.classes.configuration import Configuration
 from jsw_nx.classes.date import Date
 from jsw_nx.classes.fileutils import FileUtils as fileutils
 from jsw_nx.classes.tar import Tar as tar
 from jsw_nx.classes.json import JSON
+from jsw_nx.classes.yaml import Yaml
 from jsw_nx.classes.ymd import Ymd
