@@ -46,15 +46,12 @@ class Date:
         return time.strftime(fmt, time.localtime(ptime))
 
     @classmethod
-    def random_date_list(cls, **kwargs):
+    def random_date_list(cls, gap=75, count=10, fmt='datetime', **kwargs):
         start = kwargs.get('start')
         end = kwargs.get('end')
-        gap = kwargs.get('gap', 75)
-        count = kwargs.get('count', 10)
-        the_fmt = kwargs.get('fmt', 'datetime')
 
         no_unique_list = []
-        fmt = STANDARD_FORMAT[the_fmt] or the_fmt
+        fmt = STANDARD_FORMAT[fmt] or fmt
         for i in range(count * 2):
             last_el = no_unique_list[-1] if len(no_unique_list) > 0 else start
             no_unique_list.append(cls.random_date(last_el, end, fmt, gap))
